/**************************************************************************
 *
 * Filename:    PS3000a.java
 *
 * Copyright:   Pico Technology Limited 2011
 *
 * Author:      HSM
 *
 * Description:
 *   This is a console-mode program that demonstrates how to use the
 *   PS3000a driver.
 *
 * Examples:
 *    
 * To build this application
 *	
 *
 * History:
 *     09Sep11 Created by HSM
 *
 * Revision Info: "file %n date %f revision %v"
 *						""
 *
 ***************************************************************************/
package com.picotech.picoscope.ps3000a;

import com.picotech.picoscope.OpenUnitParameters;
import com.picotech.picoscope.PicoScope;
import com.picotech.picoscope.UnitInfo;
import com.picotech.picoscope.UnitModel;

/**
 *
 * @author hitesh
 */
public class PS3000a extends PicoScope
{
    ////////////////////////////////////////////////////////////////////////////
    //
    // Class variables
    //
    ////////////////////////////////////////////////////////////////////////////
    
    
    private PS3000aJNIWrapperAccess ps3000aJNIWrapperAccess;
    
    /**
     * Constructs a new PS3000a object
     */
    public PS3000a()
    {
        super();
        
        ps3000aJNIWrapperAccess = new PS3000aJNIWrapperAccess();
        
        openUnitParameters = new OpenUnitParameters();
        
        System.out.println("Opening PicoScope 3000A/B device...");
        
        int open_status = ps3000aJNIWrapperAccess.ps3000aOpenUnit(openUnitParameters);
        
        System.out.println("Open status: " + open_status);
        
        openedUnit = new UnitModel(openUnitParameters.getHandle());
        
        if(openedUnit.getHandle() > 0)
        {
            System.out.println("Handle: " + openedUnit.getHandle());
            unitOpened = true;
            System.out.println();
        }
        else
        {
            System.out.println("Unable to open device - exiting application.");
            System.exit(1);
        }
        
        getInfo();
    }
    
    /**
     * Obtains information on the unit.
     */
    private void getInfo()
    {
        String[] description  = { "Driver Version", "USB Version", 
                                    "Hardware Version", "Variant Info",
                                     "Batch and Serial", "Calibration Date", 
                                     "Kernel Driver Version", 
                                     "Digital Hardware Version", 
                                     "Analogue Hardware Version" };
              
        // String to accept information
        String unit_info_line = "";

        // PicoScope 3000a Series model variant
        int variant = 0;
        
        openedUnit.setUnitInfo(new UnitInfo());
        
        if(unitOpened == true)
        {
            int pico_status = getPs3000aJNIWrapperAccess().ps3000aGetUnitInfo(openedUnit.getHandle(), openedUnit.getUnitInfo());
            
            System.out.println("====== Unit Information ======");
            System.out.println(description[0] + ": " + openedUnit.getUnitInfo().getDriverVersion());
            System.out.println(description[1] + ": " + openedUnit.getUnitInfo().getUsbVersion());
            System.out.println(description[2] + ": " + openedUnit.getUnitInfo().getHardwareVersion());
            System.out.println(description[3] + ": " + openedUnit.getUnitInfo().getVariantInfo());
            System.out.println(description[4] + ": " + openedUnit.getUnitInfo().getBatchAndSerial());
            System.out.println(description[5] + ": " + openedUnit.getUnitInfo().getCalibrationDate());
            System.out.println(description[6] + ": " + openedUnit.getUnitInfo().getKernelVersion());
            System.out.println(description[7] + ": " + openedUnit.getUnitInfo().getDigitalHardwareVersion());
            System.out.println(description[8] + ": " + openedUnit.getUnitInfo().getAnalogueHardwareVersion());
            System.out.println("==============================");
            System.out.println();
            
            
            StringBuilder variant_info = new StringBuilder(openedUnit.getUnitInfo().getVariantInfo());
            //Delete the letter
            variant_info.deleteCharAt(variant_info.length() - 1);
            
            int ps3000ab_variant = 0;
            
            try
            {
                ps3000ab_variant = Integer.parseInt(variant_info.toString());
            }
            catch(NumberFormatException nfe)
            {
                System.err.println("Invalid variant string.");
                System.exit(1);            
            }
            
            System.out.println("Variant: " + ps3000ab_variant);
            
            openedUnit.setFirstRange(PS3000aData.EnPS3000ARange.PS3000A_50MV);
            openedUnit.setLastRange(PS3000aData.EnPS3000ARange.PS3000A_20V);
            openedUnit.setChannelCount((short) 4);
            
        }
        else
        {
            System.out.println("No unit opened - exiting application");
            System.exit(1);
        }
        
        
    }

    /**
     * Method to get the object containing unit handle and serial
     * 
     * @return 
     */
    public OpenUnitParameters getOpenUnitParameters() 
    {
        return openUnitParameters;
    }

    /**
     * Returns the object used to access the native code.
     * 
     * @return The ohject containing the native methods.
     */
    public PS3000aJNIWrapperAccess getPs3000aJNIWrapperAccess() 
    {
        return ps3000aJNIWrapperAccess;
    }

    /**
     * Returns a UnitModel object corresponding to the opened unit.
     * 
     * @return The opened unit
     */
    public UnitModel getOpenedUnit() 
    {
        return openedUnit;
    }
    
    public static void main(String[] args)
    {
        //System.out.println("Opening 3000a Unit...");
        
        PS3000a ps3000a = new PS3000a();
        
        short ps3000a_handle = ps3000a.getOpenUnitParameters().getHandle();
        
        System.out.println("Handle: " + ps3000a_handle);
        
        //System.out.println("Serial: " + ps3000a.getOpenUnitParameters().getSerial());
        
        System.out.println("Closing unit...");
        
        int exit_status = ps3000a.getPs3000aJNIWrapperAccess().ps3000aCloseUnit(ps3000a_handle);
        
        System.out.println("Exit status: " + exit_status);
        
        System.exit(0);
    }
}
